==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/enums/UrlFileExtensionOperator.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Describes operator to be matched
 */
public enum class UrlFileExtensionOperator(
    public val javaValue: com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator,
) : ConvertibleToJava<com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator> {
    Any(com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator.Any),
    Equal(com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator.Equal),
    Contains(com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator.Contains),
    BeginsWith(com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator.BeginsWith),
    EndsWith(com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator.EndsWith),
    LessThan(com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator.LessThan),
    LessThanOrEqual(com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator.LessThanOrEqual),
    GreaterThan(com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator.GreaterThan),
    GreaterThanOrEqual(com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator.GreaterThanOrEqual),
    RegEx(com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator.RegEx),
    ;

    override fun toJava(): com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator = javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator):
            UrlFileExtensionOperator =
            UrlFileExtensionOperator.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/enums/UrlFileExtensionOperator.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Describes operator to be matched
 */
public enum class UrlFileExtensionOperator(
    public val javaValue: com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator,
) : ConvertibleToJava<com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator> {
    Any(com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator.Any),
    Equal(com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator.Equal),
    Contains(com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator.Contains),
    BeginsWith(com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator.BeginsWith),
    EndsWith(com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator.EndsWith),
    LessThan(com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator.LessThan),
    LessThanOrEqual(com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator.LessThanOrEqual),
    GreaterThan(com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator.GreaterThan),
    GreaterThanOrEqual(com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator.GreaterThanOrEqual),
    RegEx(com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator.RegEx),
    ;

    override fun toJava(): com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator = javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.cdn.enums.UrlFileExtensionOperator): UrlFileExtensionOperator =
            UrlFileExtensionOperator.values().first { it.javaValue == javaType }
    }
}
